% ==============================================================
% CLASSE LaTeX POUR LA REDACTION DE THÈSE
% 
% Sébastien Le Roux d'après la classe écrite par Julien Chiquet
%
% Nécessite au moins un fichier de style pour la thèse
% plus le fichier de style pour les pages administratives
 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{these-seb}[2008/04/24 Classe pour ma thèse]
 
% POUR L'INSTANT UN SEUL !!!
%% Chargement de la classe book, avec transfert d'options
 
\PassOptionsToClass{a4paper}{book}
\PassOptionsToClass{12pt}{book}
\PassOptionsToClass{openright}{book}
\PassOptionsToClass{twoside}{book}
\PassOptionsToClass{francais}{book}

% french est une option globale pour que tous
% les packages qui en ont besoin puisse l'utiliser.
% L'option twoside sert a indiquer que l'on
% souhaite du recto-verso. Donc il y aura
% alternement des marges (pour que ca soit bien aligné) 
% et les parties commenceront sur des pages impaires, 
% pour etre sur des pages de droite.
% openright indique que l'on souhaite que même
% les chapitres commencent sur des pages de droite, 
% c'est a dire sur des pages impaires. 

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\DeclareOption*{}
 
\ProcessOptions
\LoadClass{book}
 
% ==============================================================
% Packages standards requis
 
% Polices et encodage

\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage[frenchb]{babel}
\frenchspacing
\RequirePackage{eurosym}
\RequirePackage{xcolor}


% ==========================================================================
% Entêtes améliorés
\RequirePackage{fancyhdr}
\RequirePackage{fancybox}

% Calcul des tailles d'environnement
\RequirePackage{calc}

% Lettrine
\RequirePackage{lettrine}
% ==========================================================================

% Configuration de la césure (-> Axel Reichert)
\tolerance = 1414
\hbadness = 1414
\emergencystretch 1.5em
\hfuzz 0.3pt
\widowpenalty=10000
\vfuzz \hfuzz
\raggedbottom
 
% =============================================
% Page de garde
\newif\ifdefinitif\definitiftrue
 
\def\titleFR#1{\gdef\@titleFR{#1}}
\def\titleEN#1{\gdef\@titleEN{#1}}
\def\abstractFR#1{\gdef\@abstractFR{#1}}
\def\abstractEN#1{\gdef\@abstractEN{#1}}
\def\keywordsFR#1{\gdef\@keywordsFR{#1}}
\def\keywordsEN#1{\gdef\@keywordsEN{#1}}
\def\@author{}
\def\address#1{\gdef\@address{#1}}
\def\universite#1{\gdef\@universite{#1}}
\def\laboratoire#1{\gdef\@laboratoire{#1}}
\def\specialite#1{\gdef\@specialite{#1}}
\def\datesoumission#1{\gdef\@datesoumission{#1}}
\def\datesoutenance#1{\gdef\@datesoutenance{#1}}
\def\jury#1{\gdef\@jury{#1}}
\def\dedicate#1{\gdef\dedication@text{#1}}
\def\greats#1{\gdef\greatings@text{#1}}
 
\renewcommand{\titlepage}{%
  \ifdefinitif
  \begin{center}    
    {\Large{{\bf{\textsc{\@universite}}}}} \\
    %\textsc{\@laboratoire} \\
    \bigskip
    \Huge\textsc{Thèse} \\ \bigskip
    \large \hbox{présentée en vu d'obtenir le grade de Docteur de l'Université de Strasbourg,} 
    spécialité \og \@specialite \fg \\ \bigskip
    par \\ \bigskip
    {\large{\@author}}
 
    \vfill
    {\Huge{\bf{\@titleFR}}}
    \vfill
 
    \normalsize
    Thèse soutenue publiquement le \@datesoutenance{} devant le jury composé de :\\
    \vspace{1cm}
    \@jury
  \end{center}
  \cleardoublepage
 
  \else
 
  % --------------------------------------------------
  % Non définitif: Page de soumission aux rapporteurs
  \thispagestyle{empty}
  \vskip3cm
  \vfill
  \begin{center}
    \large
    Manuscrit soumis aux rapporteurs, dans le but de sanctionner
    le dossier pour l'obtention du grade de \\
    Docteur en \@specialite\\
    de \\
    l'\@universite
  \end{center}
  \vskip3cm
  \begin{center}
    \huge { \@titleFR }\\ \vskip2cm
    \large \@author, le \@datesoumission\\
  \end{center}
  \vskip3cm
  \vskip3cm
  \vfill
  %\textsc{Mots-clés :} \@keywordsFR
  \fi
  \cleardoublepage
}
 
% ===========================================================
% Page de dédicace
\newcommand{\dedicacepage}{% 
  \begin{flushright}
    \em\null\vskip1in\dedication@text\vfill
  \end{flushright}
  \cleardoublepage
}

% ===========================================================
% Page de remerciements
\newcommand{\greatspage}{%
  \greatings@text\vfill
  \cleardoublepage
}

\newcommand{\abstractpage}{%
  \pagestyle{empty}
  ~\newpage
  \par
  \vfill
 
  \paragraph*{Titre}\@titleFR
  \vspace{0.125cm}
  \paragraph*{Résumé}\@abstractFR
  \vspace{0.125cm}
  \paragraph*{Mots-clés}\@keywordsFR
  \vspace{0.25cm}
  \paragraph*{Title}\@titleEN
  \vspace{0.125cm}
  \paragraph*{Abstract}\@abstractEN
  \vspace{0.125cm}
  \paragraph*{Keywords}\@keywordsEN
}
 
 
% ==========================================================================
% Mise en page
\voffset         0.0cm
\hoffset         0.0cm
\textheight     22.0cm
\textwidth      16.0cm
\topmargin       1.5cm
\oddsidemargin   0.0cm
\evensidemargin  0.0cm
 
% ==========================================================================
% Entêtes
% Entêtes standards

\fancypagestyle{plain}{
  \fancyhf{}
  \fancyfoot[RO,LE]{\thepage}
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
}
 
\fancypagestyle{main}{
  \fancyhf{}
  \fancyhead[RO]{\nouppercase{\rightmark}}
  \fancyhead[LO,RE]{\thepage}
  \fancyhead[LE]{\nouppercase{\leftmark}}
  \fancyfoot[RO,LE]{\thepage}
  \renewcommand{\headrulewidth}{1.0pt}
  \renewcommand{\footrulewidth}{0.0pt}
}

%\fancyhead{}
%\fancyhead[RO]{\scriptsize{\slshape\rightmark}}
%\fancyhead[LO]{\scriptsize{\thepage}}
%\fancyhead[RE]{\scriptsize{\thepage}}
%\fancyhead[LE]{\scriptsize{\slshape\leftmark}}
%\pagestyle{fancy}

 
% ==============================================================
% Préface
\newcommand{\beforepreface}{
  \frontmatter
  \pagestyle{empty}
  \titlepage
  \pagestyle{empty}
  \titlepage
  \strut\thispagestyle{empty}     % Je mets un truc invisible (\strut) sur la
                                  % page juste apres. On met les references ISBN
                                  % dans les bouquins. et j'indique que je ne souhaite
                                  % pas voir le numero de page (\this...{empty})
  \vfill                          % Je remplis avec du rien (\vfill}
  \pagebreak                      % Je change de page.
  \cleardoublepage

  \dedicacepage
  \greatspage
%  \pagestyle{empty}
  \pagestyle{plain}
}
 
% ==============================================================
% Contenu maître
\newcommand{\afterpreface}{
  \mainmatter
  \pagestyle{main}
}
 
% noindent en début de section
%\addto\extrasfrench{\bbl@nonfrenchindent}

% ==========================================================================
% Redéfinition d'une partie:

% Commande \part

\renewcommand\part{%
  \cleardoublepage
  \thispagestyle{empty}%
  \@tempswafalse
  \null\vfil
  \secdef\@part\@spart}

% ==========================================================================
% Aspect des têtes de parties:

\def\@spart#1{%
% \vspace*{50\p@}%
% \vspace*{10\p@}%
  {\parindent \z@ \centering \reset@font
        \thickhrulefill
        \par\nobreak
        \vspace*{10\p@}%
        \interlinepenalty\@M
        \hrule
        \vspace*{10\p@}%
        \Huge \bfseries #1 \par\nobreak
        \par
        \vspace*{10\p@}%
        \hrule
%      \vskip 40\p@
    \vskip 200\p@
  }}
 
% ==========================================================================
% Aspect des têtes de chapitre:

\makeatletter
\def\thickhrulefill{\leavevmode \leaders \hrule height 1ex \hfill \kern \z@}
\def\@makechapterhead#1{%
  %\vspace*{50\p@}%
  \vspace*{10\p@}%
  {\parindent \z@ \centering \reset@font
        \thickhrulefill\quad
        \scshape \@chapapp{} \thechapter
        \quad \thickhrulefill
        \par\nobreak
        \vspace*{10\p@}%
        \interlinepenalty\@M
        \hrule
        \vspace*{10\p@}%
        \Huge \bfseries #1\par\nobreak
        \par
        \vspace*{10\p@}%
        \hrule
    %\vskip 40\p@
    \vskip 100\p@
  }}
%\def\@makeschapterhead#1{%
  %\vspace*{50\p@}%
%  \vspace*{10\p@}%
%  {\parindent \z@ \centering \reset@font
%        \thickhrulefill
%        \par\nobreak
%        \vspace*{10\p@}%
%        \interlinepenalty\@M
%        \hrule
%        \vspace*{10\p@}%
%        \Huge \bfseries #1\par\nobreak
%        \par
%        \vspace*{10\p@}%
%        \hrule
%    %\vskip 40\p@
%    \vskip 100\p@
%  }}

\RequirePackage[hyperpageref]{backref}
\backreffrench
%\renewcommand*{\backref}[1]{}  % Disable standard
\renewcommand*{\backrefalt}[4]{% Detailed backref
  \ifcase #1 %
  \relax%(Not cited.)%
  \or
  (Page~#2.)%
  \else
  (Pages~#2.) 
  \fi}
 
% Page blanche après chapitre si nécessaire
\makeatletter
\def\cleardoublepage{\clearpage\if@twoside \ifodd\c@page\else
  \hbox{}
  \vspace*{\fill}
  \begin{center}
    ~
  \end{center}
  \vspace{\fill}
  \thispagestyle{empty}
  \newpage
  \if@twocolumn\hbox{}\newpage\fi\fi\fi}
\makeatother
 
% ---------------------------------------------------------------
% Lettrine
\newcommand{\malettrine}[1]{
  \lettrine[lines=2,lhang=0.33,loversize=0.33]{#1}
}
  
% ==========================================================================
% Colophon
\newcommand{\colophon}[1]{
  \strut\thispagestyle{empty}  
  \vfill                          % Je remplis avec du rien (\vfill}
  \pagebreak                     
  \thispagestyle{empty}
  ~\vfill
  \begin{center}
    \small #1
  \end{center}
  \cleardoublepage
}
